Code coverage report for js/dialogs/errorDialog.tsx

# All files / js/dialogs errorDialog.tsx

75% Statements 3/4
100% Branches 0/0
0% Functions 0/1
75% Lines 3/4

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    28
    29
    30
    31
    32
    33
    341x
    1x
    1x

     import React, { Component } from "react";
    import SlideDialog from "../components/SlideDialog";
    import { trans } from "../i18n";

    export default class ErrorDialog extends Component<
      { dismiss: () => void; error: any },
      unknown
    > {
      render() {
        return (
          <SlideDialog
            dismiss={this.props.dismiss}
            hasCloseButton
            title={trans("ERROR")}
          >
            <p>
              {trans("ERROR_OCURRED")}
              {": "}
              {trans("ERROR_" + this.props.error.code)}
            </p>
            <p>
              <button
                type="submit"
                className="btn btn-primary"
                onClick={this.props.dismiss}
              >
                {trans("CLOSE")}
              </button>
            </p>
          </SlideDialog>
        );
      }
    }